ArcField

Struct ArcField 

pub struct ArcField<T>
where T: 'static,
{ /* private fields */ }
Reference-counted access to a single field of type T.

This can be used to erase the chain of field-accessors, to make it easier to pass this into another component or function without needing to specify the full type signature.