Struct StorePath

pub struct StorePath(/* private fields */);
The path of a field within some store.

Implementations

Source

impl StorePath

pub fn push(&mut self, segment: impl Into<StorePathSegment>)

Adds a new segment to the path.

pub fn pop(&mut self) -> Option<StorePathSegment>

Removes a segment from the path and returns it.

pub fn replace_last(&mut self, segment: impl Into<StorePathSegment>)

Updates the last segment in the place in place.

pub fn is_empty(&self) -> bool

Returns true if the path contains no elements.

pub fn len(&self) -> usize

Returns the number of elements in the path.