pub struct StorePath(/* private fields */);Expand description
The path of a field within some store.
Implementations
Sourceimpl StorePath
impl StorePath
Sourcepub fn push(&mut self, segment: impl Into<StorePathSegment>)
pub fn push(&mut self, segment: impl Into<StorePathSegment>)
Adds a new segment to the path.
Sourcepub fn pop(&mut self) -> Option<StorePathSegment>
pub fn pop(&mut self) -> Option<StorePathSegment>
Removes a segment from the path and returns it.
Sourcepub fn replace_last(&mut self, segment: impl Into<StorePathSegment>)
pub fn replace_last(&mut self, segment: impl Into<StorePathSegment>)
Updates the last segment in the place in place.