Trait PatchField

pub trait PatchField {
    // Required method
    fn patch_field(
        &mut self,
        new: Self,
        path: &StorePath,
        notify: &mut dyn FnMut(&StorePath),
    );
}
Allows patching a store field with some new value.

Required Methods

fn patch_field( &mut self, new: Self, path: &StorePath, notify: &mut dyn FnMut(&StorePath), )

Patches the field with some new value, only notifying if the value has changed.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementations on Foreign Types

Source

impl PatchField for &str

Source

fn patch_field( &mut self, new: Self, path: &StorePath, notify: &mut dyn FnMut(&StorePath), )

Source

impl PatchField for Cow<'_, str>

Source

fn patch_field( &mut self, new: Self, path: &StorePath, notify: &mut dyn FnMut(&StorePath), )

Source

impl PatchField for IpAddr

Source

fn patch_field( &mut self, new: Self, path: &StorePath, notify: &mut dyn FnMut(&StorePath), )

Source

impl PatchField for SocketAddr

Source

fn patch_field( &mut self, new: Self, path: &StorePath, notify: &mut dyn FnMut(&StorePath), )

Source

impl PatchField for bool

Source

fn patch_field( &mut self, new: Self, path: &StorePath, notify: &mut dyn FnMut(&StorePath), )

Source

impl PatchField for char

Source

fn patch_field( &mut self, new: Self, path: &StorePath, notify: &mut dyn FnMut(&StorePath), )

Source

impl PatchField for f32

Source

fn patch_field( &mut self, new: Self, path: &StorePath, notify: &mut dyn FnMut(&StorePath), )

Source

impl PatchField for f64

Source

fn patch_field( &mut self, new: Self, path: &StorePath, notify: &mut dyn FnMut(&StorePath), )

Source

impl PatchField for i8

Source

fn patch_field( &mut self, new: Self, path: &StorePath, notify: &mut dyn FnMut(&StorePath), )

Source

impl PatchField for i16

Source

fn patch_field( &mut self, new: Self, path: &StorePath, notify: &mut dyn FnMut(&StorePath), )

Source

impl PatchField for i32

Source

fn patch_field( &mut self, new: Self, path: &StorePath, notify: &mut dyn FnMut(&StorePath), )

Source

impl PatchField for i64

Source

fn patch_field( &mut self, new: Self, path: &StorePath, notify: &mut dyn FnMut(&StorePath), )

Source

impl PatchField for i128

Source

fn patch_field( &mut self, new: Self, path: &StorePath, notify: &mut dyn FnMut(&StorePath), )

Source

impl PatchField for isize

Source

fn patch_field( &mut self, new: Self, path: &StorePath, notify: &mut dyn FnMut(&StorePath), )

Source

impl PatchField for u8

Source

fn patch_field( &mut self, new: Self, path: &StorePath, notify: &mut dyn FnMut(&StorePath), )

Source

impl PatchField for u16

Source

fn patch_field( &mut self, new: Self, path: &StorePath, notify: &mut dyn FnMut(&StorePath), )

Source

impl PatchField for u32

Source

fn patch_field( &mut self, new: Self, path: &StorePath, notify: &mut dyn FnMut(&StorePath), )

Source

impl PatchField for u64

Source

fn patch_field( &mut self, new: Self, path: &StorePath, notify: &mut dyn FnMut(&StorePath), )

Source

impl PatchField for u128

Source

fn patch_field( &mut self, new: Self, path: &StorePath, notify: &mut dyn FnMut(&StorePath), )

Source

impl PatchField for ()

Source

fn patch_field( &mut self, _new: Self, _path: &StorePath, _notify: &mut dyn FnMut(&StorePath), )

Source

impl PatchField for usize

Source

fn patch_field( &mut self, new: Self, path: &StorePath, notify: &mut dyn FnMut(&StorePath), )

Source

impl PatchField for Rc<str>

Source

fn patch_field( &mut self, new: Self, path: &StorePath, notify: &mut dyn FnMut(&StorePath), )

Source

impl PatchField for String

Source

fn patch_field( &mut self, new: Self, path: &StorePath, notify: &mut dyn FnMut(&StorePath), )

Source

impl PatchField for Arc<str>

Source

fn patch_field( &mut self, new: Self, path: &StorePath, notify: &mut dyn FnMut(&StorePath), )

Source

impl PatchField for Ipv4Addr

Source

fn patch_field( &mut self, new: Self, path: &StorePath, notify: &mut dyn FnMut(&StorePath), )

Source

impl PatchField for Ipv6Addr

Source

fn patch_field( &mut self, new: Self, path: &StorePath, notify: &mut dyn FnMut(&StorePath), )

Source

impl PatchField for SocketAddrV4

Source

fn patch_field( &mut self, new: Self, path: &StorePath, notify: &mut dyn FnMut(&StorePath), )

Source

impl PatchField for SocketAddrV6

Source

fn patch_field( &mut self, new: Self, path: &StorePath, notify: &mut dyn FnMut(&StorePath), )

Source

impl PatchField for NonZeroI8

Source

fn patch_field( &mut self, new: Self, path: &StorePath, notify: &mut dyn FnMut(&StorePath), )

Source

impl PatchField for NonZeroI16

Source

fn patch_field( &mut self, new: Self, path: &StorePath, notify: &mut dyn FnMut(&StorePath), )

Source

impl PatchField for NonZeroI32

Source

fn patch_field( &mut self, new: Self, path: &StorePath, notify: &mut dyn FnMut(&StorePath), )

Source

impl PatchField for NonZeroI64

Source

fn patch_field( &mut self, new: Self, path: &StorePath, notify: &mut dyn FnMut(&StorePath), )

Source

impl PatchField for NonZeroI128

Source

fn patch_field( &mut self, new: Self, path: &StorePath, notify: &mut dyn FnMut(&StorePath), )

Source

impl PatchField for NonZeroIsize

Source

fn patch_field( &mut self, new: Self, path: &StorePath, notify: &mut dyn FnMut(&StorePath), )

Source

impl PatchField for NonZeroU8

Source

fn patch_field( &mut self, new: Self, path: &StorePath, notify: &mut dyn FnMut(&StorePath), )

Source

impl PatchField for NonZeroU16

Source

fn patch_field( &mut self, new: Self, path: &StorePath, notify: &mut dyn FnMut(&StorePath), )

Source

impl PatchField for NonZeroU32

Source

fn patch_field( &mut self, new: Self, path: &StorePath, notify: &mut dyn FnMut(&StorePath), )

Source

impl PatchField for NonZeroU64

Source

fn patch_field( &mut self, new: Self, path: &StorePath, notify: &mut dyn FnMut(&StorePath), )

Source

impl PatchField for NonZeroU128

Source

fn patch_field( &mut self, new: Self, path: &StorePath, notify: &mut dyn FnMut(&StorePath), )

Source

impl PatchField for NonZeroUsize

Source

fn patch_field( &mut self, new: Self, path: &StorePath, notify: &mut dyn FnMut(&StorePath), )

Source

impl<A> PatchField for (A,)
where A: PatchField,

Source

fn patch_field( &mut self, new: Self, path: &StorePath, notify: &mut dyn FnMut(&StorePath), )

Source

impl<A, B> PatchField for (A, B)
where A: PatchField, B: PatchField,

Source

fn patch_field( &mut self, new: Self, path: &StorePath, notify: &mut dyn FnMut(&StorePath), )

Source

impl<A, B, C> PatchField for (A, B, C)
where A: PatchField, B: PatchField, C: PatchField,

Source

fn patch_field( &mut self, new: Self, path: &StorePath, notify: &mut dyn FnMut(&StorePath), )

Source

impl<A, B, C, D> PatchField for (A, B, C, D)

Source

fn patch_field( &mut self, new: Self, path: &StorePath, notify: &mut dyn FnMut(&StorePath), )

Source

impl<A, B, C, D, E> PatchField for (A, B, C, D, E)

Source

fn patch_field( &mut self, new: Self, path: &StorePath, notify: &mut dyn FnMut(&StorePath), )

Source

impl<A, B, C, D, E, F> PatchField for (A, B, C, D, E, F)

Source

fn patch_field( &mut self, new: Self, path: &StorePath, notify: &mut dyn FnMut(&StorePath), )

Source

impl<A, B, C, D, E, F, G> PatchField for (A, B, C, D, E, F, G)

Source

fn patch_field( &mut self, new: Self, path: &StorePath, notify: &mut dyn FnMut(&StorePath), )

Source

impl<A, B, C, D, E, F, G, H> PatchField for (A, B, C, D, E, F, G, H)

Source

fn patch_field( &mut self, new: Self, path: &StorePath, notify: &mut dyn FnMut(&StorePath), )

Source

impl<A, B, C, D, E, F, G, H, I> PatchField for (A, B, C, D, E, F, G, H, I)

Source

fn patch_field( &mut self, new: Self, path: &StorePath, notify: &mut dyn FnMut(&StorePath), )

Source

impl<A, B, C, D, E, F, G, H, I, J> PatchField for (A, B, C, D, E, F, G, H, I, J)

Source

fn patch_field( &mut self, new: Self, path: &StorePath, notify: &mut dyn FnMut(&StorePath), )

Source

impl<A, B, C, D, E, F, G, H, I, J, K> PatchField for (A, B, C, D, E, F, G, H, I, J, K)

Source

fn patch_field( &mut self, new: Self, path: &StorePath, notify: &mut dyn FnMut(&StorePath), )

Source

impl<A, B, C, D, E, F, G, H, I, J, K, L> PatchField for (A, B, C, D, E, F, G, H, I, J, K, L)

Source

fn patch_field( &mut self, new: Self, path: &StorePath, notify: &mut dyn FnMut(&StorePath), )

Source

impl<A, B, C, D, E, F, G, H, I, J, K, L, M> PatchField for (A, B, C, D, E, F, G, H, I, J, K, L, M)

Source

fn patch_field( &mut self, new: Self, path: &StorePath, notify: &mut dyn FnMut(&StorePath), )

Source

impl<A, B, C, D, E, F, G, H, I, J, K, L, M, N> PatchField for (A, B, C, D, E, F, G, H, I, J, K, L, M, N)

Source

fn patch_field( &mut self, new: Self, path: &StorePath, notify: &mut dyn FnMut(&StorePath), )

Source

impl<A, B, C, D, E, F, G, H, I, J, K, L, M, N, O> PatchField for (A, B, C, D, E, F, G, H, I, J, K, L, M, N, O)

Source

fn patch_field( &mut self, new: Self, path: &StorePath, notify: &mut dyn FnMut(&StorePath), )

Source

impl<A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P> PatchField for (A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P)

Source

fn patch_field( &mut self, new: Self, path: &StorePath, notify: &mut dyn FnMut(&StorePath), )

Source

impl<A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q> PatchField for (A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q)

Source

fn patch_field( &mut self, new: Self, path: &StorePath, notify: &mut dyn FnMut(&StorePath), )

Source

impl<A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q, R> PatchField for (A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q, R)

Source

fn patch_field( &mut self, new: Self, path: &StorePath, notify: &mut dyn FnMut(&StorePath), )

Source

impl<A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q, R, S> PatchField for (A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q, R, S)

Source

fn patch_field( &mut self, new: Self, path: &StorePath, notify: &mut dyn FnMut(&StorePath), )

Source

impl<A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q, R, S, T> PatchField for (A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q, R, S, T)

Source

fn patch_field( &mut self, new: Self, path: &StorePath, notify: &mut dyn FnMut(&StorePath), )

Source

impl<A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q, R, S, T, U> PatchField for (A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q, R, S, T, U)

Source

fn patch_field( &mut self, new: Self, path: &StorePath, notify: &mut dyn FnMut(&StorePath), )

Source

impl<A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q, R, S, T, U, V> PatchField for (A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q, R, S, T, U, V)

Source

fn patch_field( &mut self, new: Self, path: &StorePath, notify: &mut dyn FnMut(&StorePath), )

Source

impl<A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q, R, S, T, U, V, W> PatchField for (A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q, R, S, T, U, V, W)

Source

fn patch_field( &mut self, new: Self, path: &StorePath, notify: &mut dyn FnMut(&StorePath), )

Source

impl<A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q, R, S, T, U, V, W, X> PatchField for (A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q, R, S, T, U, V, W, X)

Source

fn patch_field( &mut self, new: Self, path: &StorePath, notify: &mut dyn FnMut(&StorePath), )

Source

impl<A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q, R, S, T, U, V, W, X, Y> PatchField for (A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q, R, S, T, U, V, W, X, Y)

Source

fn patch_field( &mut self, new: Self, path: &StorePath, notify: &mut dyn FnMut(&StorePath), )

Source

impl<A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q, R, S, T, U, V, W, X, Y, Z> PatchField for (A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q, R, S, T, U, V, W, X, Y, Z)

Source

fn patch_field( &mut self, new: Self, path: &StorePath, notify: &mut dyn FnMut(&StorePath), )

Source

impl<T> PatchField for Option<T>
where T: PatchField,

Source

fn patch_field( &mut self, new: Self, path: &StorePath, notify: &mut dyn FnMut(&StorePath), )

Source

impl<T> PatchField for Vec<T>
where T: PatchField,

Source

fn patch_field( &mut self, new: Self, path: &StorePath, notify: &mut dyn FnMut(&StorePath), )

Implementors