pub trait PatchField {
// Required method
fn patch_field(
&mut self,
new: Self,
path: &StorePath,
notify: &mut dyn FnMut(&StorePath),
);
}Expand description
Allows patching a store field with some new value.
Required Methods
Sourcefn patch_field(
&mut self,
new: Self,
path: &StorePath,
notify: &mut dyn FnMut(&StorePath),
)
fn patch_field( &mut self, new: Self, path: &StorePath, notify: &mut dyn FnMut(&StorePath), )
Patches the field with some new value, only notifying if the value has changed.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.